package fragment;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import androidx.fragment.app.Fragment;

import com.akamai.amp.captioning.AmpCaptionComponent;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.amp.media.IPlayerEventsListener;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;

public class EIAFragment extends Fragment
        implements View.OnTouchListener, IPlayerEventsListener {

    private final static String TAG = "AMP-CC-CEA608";
    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/worldnow/608/master.m3u8";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar mProgressBar;


    private AmpCaptionComponent captionComponent;


    public static EIAFragment newInstance() {
        EIAFragment fragment = new EIAFragment();
        return fragment;
    }

    public EIAFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        captionComponent = (AmpCaptionComponent) rootView.findViewById(R.id.captionView);

        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                videoPlayerView = mVideoContainer.getVideoPlayer();
                videoPlayerView.setProgressBarControl(mProgressBar);
                videoPlayerView.setLicense(MainActivity.LICENSE);
                videoPlayerView.setFullScreen(true);
                videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                videoPlayerView.setLogEnabled(true);

                captionComponent.setVideoPlayerView(videoPlayerView);

                videoPlayerView.addEventsListener(EIAFragment.this);
                videoPlayerView.setKeepScreenOn(true);
                videoPlayerView.setOnTouchListener(EIAFragment.this);

                videoPlayerView.play(mediaResource);
            }

            @Override
            public void onResourceError(ErrorType errorType, Exception exception) {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);

        return rootView;
    }

    @Override
    public void onResume() {
        Log.d(TAG, "OnResume");
        if (videoPlayerView != null) {
            videoPlayerView.onResume();
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d(TAG, "OnPause");
        if(videoPlayerView != null){
            videoPlayerView.onPause();
        }
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d(TAG, "OnDestroy");
        if (videoPlayerView!=null) {
            videoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int eventID) {
        if (eventID == IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING)
            captionComponent.setIndexes(0, 0);

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int eventID, int arg1, int arg2) {
        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }
}
